==> sight_21.0.0.orig.tar.gz: sight-21.0.0/libs/filter/image/test/tu/PowellOptimizerTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2018-2021 IRCAD France
 * Copyright (C) 2018-2021 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <cppunit/extensions/HelperMacros.h>

namespace sight::filter::image
{

namespace ut
{

/**
 * @brief Optimizer tests. Find the minimum of some popular functions.
 *
 * Common test functions were found [here](https://en.wikipedia.org/wiki/Test_functions_for_optimization).
 */
class PowellOptimizerTest : public CPPUNIT_NS::TestFixture
{
CPPUNIT_TEST_SUITE(PowellOptimizerTest);
CPPUNIT_TEST(parabolaTest);
CPPUNIT_TEST(ackleyTest);
CPPUNIT_TEST(sphereFunctionTest);
CPPUNIT_TEST(bealeFunctionTest);
CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp();
    void tearDown();

    void parabolaTest();
    void ackleyTest();
    void sphereFunctionTest();
    void bealeFunctionTest();
};

} //namespace ut.

} //namespace sight::filter::image.

==> sight_23.1.0.orig.tar.gz: sight-23.1.0/libs/filter/image/test/tu/PowellOptimizerTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2018-2022 IRCAD France
 * Copyright (C) 2018-2021 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <cppunit/extensions/HelperMacros.h>

namespace sight::filter::image::ut
{

/**
 * @brief Optimizer tests. Find the minimum of some popular functions.
 *
 * Common test functions were found [here](https://en.wikipedia.org/wiki/Test_functions_for_optimization).
 */
class PowellOptimizerTest : public CPPUNIT_NS::TestFixture
{
CPPUNIT_TEST_SUITE(PowellOptimizerTest);
CPPUNIT_TEST(parabolaTest);
CPPUNIT_TEST(ackleyTest);
CPPUNIT_TEST(sphereFunctionTest);
CPPUNIT_TEST(bealeFunctionTest);
CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp() override;
    void tearDown() override;

    static void parabolaTest();
    static void ackleyTest();
    static void sphereFunctionTest();
    static void bealeFunctionTest();
};

} // namespace sight::filter::image::ut
